searchData={"items":[{"type":"module","title":"Matplotex","doc":"A lightweight and efficient Elixir library designed for server-side SVG generation, ideal for data visualization in web applications. It integrates seamlessly with Phoenix LiveView and provides powerful tools for generating dynamic visualizations.","ref":"Matplotex.html"},{"type":"module","title":"Supported Graph Types - Matplotex","doc":"Matplotex supports the following types of visualizations:\n\n- Line Plots\n- Bar Charts\n- Pie Charts\n- Spline Graphs\n- Histograms\n- Scatter Plots","ref":"Matplotex.html#module-supported-graph-types"},{"type":"module","title":"Examples - Matplotex","doc":"```elixir\nalias Matplotex as: M\n\n  x = [1, 2, 3, 4, 6, 6, 7]\n  y = [1, 3, 4, 4, 5, 6, 7]\n\n  frame_width = 6\n  frame_height = 6\n  size = {frame_width, frame_height}\n  margin = 0.05\n  font_size = \"16pt\"\n  title_font_size = \"18pt\"\n  ticks = [1, 2, 3, 4, 5, 6, 7]\n\n  x\n  |> M.plot(y)\n  |> M.figure(%{figsize: size, margin: margin})\n  |> M.set_title(\"The Plot Title\")\n  |> M.set_xlabel(\"X Axis\")\n  |> M.set_ylabel(\"Y Axis\")\n  |> M.set_xticks(ticks)\n  |> M.set_yticks(ticks)\n  |> M.set_xlim({4, 7})\n  |> M.set_ylim({4, 7})\n  |> M.set_rc_params(\n    x_tick_font_size: font_size,\n    y_tick_font_size: font_size,\n    title_font_size: title_font_size,\n    x_label_font_size: font_size,\n    y_label_font_size: font_size,\n    title_font_size: title_font_size\n  )\n  |> M.show()\n```\n\n```elixir\nalis Matplotex as: M\n x = [1, 2, 3, 4, 6, 6, 7]\n  y = [1, 3, 4, 4, 5, 6, 7]\n\n  frame_width = 6\n  frame_height = 6\n  size = {frame_width, frame_height}\n  margin = 0.05\n  font_size = \"16pt\"\n  title_font_size = \"18pt\"\n  ticks = [0, 1, 2, 3, 4, 5, 6, 7]\n\n  x\n  |> M.plot(y,\n    figsize: size,\n    margin: margin,\n    title: \"The plot title\",\n    x_label: \"X Axis\",\n    y_label: \"Y Axis\",\n    x_tick: ticks,\n    y_tick: ticks,\n    x_limit: {0, 7},\n    y_limit: {0, 7},\n    x_tick_font_size: font_size,\n    y_tick_font_size: font_size,\n    title_font_size: title_font_size,\n    x_label_font_size: font_size,\n    y_label_font_size: font_size,\n    y_tick_font_text_anchor: \"start\"\n  )\n  |> M.show()\n```\n**Note**: Both approaches are equivalent, and users can choose whichever pattern is more convenient.","ref":"Matplotex.html#module-examples"},{"type":"module","title":"Runtime Configuration (RC Params) - Matplotex","doc":"The function M.set_rc_params/2 allows you to set runtime configuration parameters for the plot, such as font sizes, colors, and line styles. These settings affect visual elements like the font style and size for the labels, ticks, and title.\n\nBy default, the plot starts with standard values (e.g., Arial or Verdana font, size 12). You can modify these using the RC parameters.","ref":"Matplotex.html#module-runtime-configuration-rc-params"},{"type":"module","title":"Available RC Params: - Matplotex","doc":"line_width, line_style\ngrid_color, grid_linestyle, grid_alpha\ntick_line_length\nx_padding, y_padding, padding\nlegend_width\nRefer to specific plot documentation for detailed information on padding usage.","ref":"Matplotex.html#module-available-rc-params"},{"type":"module","title":"Elements - Matplotex","doc":"The output format of the plot is SVG will support more formats in future, anyway the svg is a group of some elements put together, throught the execution\nit is generating those elements through elixir data structure, all element data structure contains some svg equivalent data that converts the elements to\nSVG string, the output SVG string can be used directly in the web application.","ref":"Matplotex.html#module-elements"},{"type":"module","title":"Figure Data Structure - Matplotex","doc":"The main data structure used to generate a plot is Matplotex.Figure, which contains all the necessary information for the plot, including:\n\n- `:figsize`: A tuple specifying the width and height of the figure (e.g., {10, 6}).\n- `:axes`: Contains the axes data, which varies depending on the plot type.\n- `:rc_params`: The runtime configuration parameters.\n- `:margin`: Specifies the margin of the figure.\n\n## `M.show/1`\nAfter creating a figure using the functions provided,  call M.show/1 to generate and display the final SVG representation of the plot. The show/1 function will convert the Matplotex.Figure data into a valid SVG string.","ref":"Matplotex.html#module-figure-data-structure"},{"type":"module","title":"Matplotex.Figure.Areal behaviour - Matplotex","doc":"Matplotex goes beyond basic chart generation, offering a user-friendly interface for creating custom plots. It leverages two key behaviors: Matplotex.Figure.Areal and Matplotex.Element. The Areal module handles the underlying linear transformations, abstracting away unnecessary complexity. Users can seamlessly integrate SVG strings by defining structs that implement the Element behavior. Mapping data series to these elements is then achieved through the Matplotex.Figure.Areal behavior, making it a compelling tool for custom visualization.\nExample usage:\n ```elixir\n    defmodule MyCustomAreaChart do\n        use Matplotex.Figure.Areal\n\n          frame(\n          tick: %TwoD{},\n          limit: %TwoD{},\n          label: %TwoD{},\n          region_x: %Region{},\n          region_y: %Region{},\n          region_title: %Region{},\n          region_legend: %Region{},\n          region_content: %Region{}\n          )\n\n\n        def create(figure, data, _opts) do\n        dataset = Dataset.cast(%Dataset{x: x, y: y}, opts)\n\n        %Figure{figure | axes: %{axes | data: xydata, dataset: datasets}}\n        |> PlotOptions.set_options_in_figure(opts)\n        end\n\n        def materialize(figure) do\n          materialize_chart_elements(figure)\n        end\n        defp materialize_chart_elements(%Figure{axes: %__MODULE__{elements: elements}}) do\n        elements ++ [%CustomElement{}]\n        end\n  ```\n  * Figure: A common struct used by all chart APIs in the library, serving as both input and output for consistent handling.\n\n  * Axes: A struct containing all chart-specific information.\n\n  * Dataset: A modular data input structure. The axes struct expects a list of %Dataset{} structs for converting data points into their SVG element equivalents.\n\n  * Custom Elements: The materializer function's primary role is to generate a list of structs that implement the Matplotex.Element behavior. This enables the SVG generator to produce the appropriate tags for custom visualizations","ref":"Matplotex.html#module-matplotex-figure-areal-behaviour"},{"type":"module","title":"Matplotex.Element behaviour - Matplotex","doc":"The Matplotex.Element behavior defines a callback function, assemble/1, which takes a struct as input and returns its corresponding SVG tag as a string. The assemble/1 function is responsible for interpolating the struct's values into the SVG element.","ref":"Matplotex.html#module-matplotex-element-behaviour"},{"type":"function","title":"Matplotex.bar/2","doc":"Generates a bar chart using the provided values and bar widths.","ref":"Matplotex.html#bar/2"},{"type":"function","title":"Parameters - Matplotex.bar/2","doc":"- `values` (list of numbers): A list of numerical values representing the heights of the bars in the chart.\n  - `width` (floatiung point number): The width of each bar in inches.\n  - `opts` (keyword list): It will support all opts mentioned above, some bar specific options are there those are\n      - `:label` (string): Label for specific dataset passed on first argument.\n      - `:color` (string): Color of the bar.\n      - `:edge_color` (string): Color of the edge of the bar.","ref":"Matplotex.html#bar/2-parameters"},{"type":"function","title":"Returns - Matplotex.bar/2","doc":"- A figure with the axes of a bar chart\n```elixir\n\n    alias Matplotex as: M\n  categories = [\"apple\", \"banana\", \"fig\", \"avocado\"]\n    values1 = [22, 33, 28, 34]\n    iex> Matplotex.bar(width, values1, width, label: \"Dataset1\", color: \"#255199\")\n    %M.Figure{axes: %M.Figure.Areal.BarChart{...}, ...}\n  ```\n\nThis function takes a list of numerical `values` and a single `width` value to create a bar chart where:\n  - The height of each bar corresponds to its respective value from the list.\n  - Each bar has the specified constant width.","ref":"Matplotex.html#bar/2-returns"},{"type":"function","title":"Matplotex.bar/3","doc":"","ref":"Matplotex.html#bar/3"},{"type":"function","title":"Matplotex.bar/4","doc":"","ref":"Matplotex.html#bar/4"},{"type":"function","title":"Matplotex.bar/5","doc":"Adds an additional dataset to a bar plot in the given `%Figure{}`.\n\nThis function allows you to append multiple datasets to a bar plot by providing new values and corresponding options. Each dataset can be customized with options such as color, label, and bar width.","ref":"Matplotex.html#bar/5"},{"type":"function","title":"Parameters - Matplotex.bar/5","doc":"- `figure` (%Figure{}): The figure to which the new dataset will be added.\n  - `values` (list): A list of numerical values representing the heights of the bars in the new dataset.\n  - `width` (float): The width of the bars in the dataset.\n  - `opts` (keyword list, optional): A set of options for customizing the appearance of the new dataset, such as color and label.","ref":"Matplotex.html#bar/5-parameters"},{"type":"function","title":"Usage - Matplotex.bar/5","doc":"This function is used when generating multi-bar plots to represent data from multiple datasets. Here's an example demonstrating its usage:\n\n```elixir\nalias Matplotex, as: M\n\ncategories = [\"apple\", \"banana\", \"fig\", \"avocado\"]\nvalues1 = [22, 33, 28, 34]\nvalues2 = [53, 63, 59, 60]\nwidth = 0.22\n\nMatplotex.bar(width, values1, width, label: \"Dataset1\", color: \"#255199\")\n|> M.bar(width, values2, width, label: \"Dataset2\", color: \"#D3D3D3\")","ref":"Matplotex.html#bar/5-usage"},{"type":"function","title":"Matplotex.figure/2","doc":"Adds legend for the graph with given details","ref":"Matplotex.html#figure/2"},{"type":"function","title":"Examples - Matplotex.figure/2","doc":"iex> Matplotex.legend(figure, labels: [\"A\", \"B\", \"C\"])\n    %Matplotex.Figure{}","ref":"Matplotex.html#figure/2-examples"},{"type":"function","title":"The `opts` are - Matplotex.figure/2","doc":"`labels, title, position, size`","ref":"Matplotex.html#figure/2-the-opts-are"},{"type":"function","title":"Matplotex.hide_v_grid/1","doc":"","ref":"Matplotex.html#hide_v_grid/1"},{"type":"function","title":"Matplotex.hist/2","doc":"Creates a histogram with the given data and bins.\n\nThis function generates a histogram visualization using the provided data, number of bins, and additional plot configuration options.","ref":"Matplotex.html#hist/2"},{"type":"function","title":"Parameters - Matplotex.hist/2","doc":"- `data`: list of random distributions of numbers\n - `bins`: number of bins to get the density of each distribution\n - `opts` (keyword list, optional): additional plot configuration options, such as, color, edge color, alpha","ref":"Matplotex.html#hist/2-parameters"},{"type":"function","title":"Examples - Matplotex.hist/2","doc":"```elixir\n# Generate a list of random values from a normal distribution\nvalues =\n  Nx.Random.key(12)\n  |> Nx.Random.normal(0, 1, shape: {1000})\n  |> elem(0)\n  |> Nx.to_list()\n\n# Specify the number of bins for the histogram\nbins = 30\n\n# Create the histogram with labels, title, and styling\nMatplotex.hist(\n  values,\n  bins,\n  x_label: \"Value\",\n  y_label: \"Frequency\",\n  title: \"Histogram\",\n  color: \"blue\",\n  edge_color: \"black\",\n  alpha: 0.7,\n  x_ticks_count: 9\n)","ref":"Matplotex.html#hist/2-examples"},{"type":"function","title":"Matplotex.hist/3","doc":"Adds an additional dataset to a histogram plot.\n\nThis function allows you to overlay multiple datasets on the same figure, enabling the creation of combined histograms for comparative analysis.","ref":"Matplotex.html#hist/3"},{"type":"function","title":"Parameters - Matplotex.hist/3","doc":"- `figure` (%Figure{}): The figure to which the new dataset will be added.\n- `data` (list): A list of random numbers representing the distribution to be added.\n- `bins` (integer): The number of bins to divide the dataset into for density calculation.","ref":"Matplotex.html#hist/3-parameters"},{"type":"function","title":"Usage - Matplotex.hist/3","doc":"Use this function when you need to generate multiple histograms from different datasets on the same figure. This is particularly useful for comparing distributions.","ref":"Matplotex.html#hist/3-usage"},{"type":"function","title":"Example - Matplotex.hist/3","doc":"```elixir\n# Generate the first dataset\nvalues1 =\n  Nx.Random.key(12)\n  |> Nx.Random.normal(0, 1, shape: {1000})\n  |> elem(0)\n  |> Nx.to_list()\n\n# Generate the second dataset\nvalues2 =\n  Nx.Random.key(13)\n  |> Nx.Random.normal(0, 1, shape: {500})\n  |> elem(0)\n  |> Nx.to_list()\n\n# Define the number of bins\nbins = 30\n\n# Create a histogram with multiple datasets\nMatplotex.hist(values1, bins,\n  x_label: \"Value\",\n  y_label: \"Frequency\",\n  title: \"Histogram\",\n  color: \"blue\",\n  edge_color: \"black\",\n  alpha: 0.7,\n  x_ticks_count: 9\n)\n|> Matplotex.hist(values2, bins, color: \"red\")","ref":"Matplotex.html#hist/3-example"},{"type":"function","title":"Matplotex.hist/4","doc":"","ref":"Matplotex.html#hist/4"},{"type":"function","title":"Matplotex.pie/2","doc":"Generates a pie chart based on the provided data, labels, and options.","ref":"Matplotex.html#pie/2"},{"type":"function","title":"Parameters: - Matplotex.pie/2","doc":"- `sizes` (list of integers/floats): Percentages or proportions for each slice of the pie chart.\n- `opts` (keyword list): Options to customize the chart, such as:\n  - `:labels` (list of strings): Labels for each slice.\n  - `:colors` (list of strings): Colors for the slices.","ref":"Matplotex.html#pie/2-parameters"},{"type":"function","title":"Example: - Matplotex.pie/2","doc":"```elixir\n# Percentages for each slice\nsizes = [25, 35, 20, 20]\n\n# Labels for each slice\nlabels = [\"A\", \"B\", \"C\", \"D\"]\n\n# Colors for the slices\ncolors = [\"lightblue\", \"lightgreen\", \"orange\", \"pink\"]\n\n# Generate the pie chart\nsizes\n|> Matplotex.pie(colors: colors, labels: labels)\n\n%M.Figure{axes: %Matplotex.Figure.Radial.Pie{...}, ...}","ref":"Matplotex.html#pie/2-example"},{"type":"function","title":"Matplotex.plot/2","doc":"Generates a line plot using the provided `x` and `y` data points.\n##Parameters\n`x`: A list of x-coordinates for the data points (e.g., [1, 2, 3]).\n`y`: A list of y-coordinates corresponding to x (e.g., [2, 4, 6]).\n`opts`:  it also expect some plot specific options such as\n     `color`: line color\n     `linestyle`: line style\n     `marker`: marker style","ref":"Matplotex.html#plot/2"},{"type":"function","title":"Example - Matplotex.plot/2","doc":"```elixir\n# Define the data points\nx = [1, 2, 3, 4, 6, 6, 7]\ny = [1, 3, 4, 4, 5, 6, 7]\n\n# Specify plot configurations\nframe_width = 6\nframe_height = 6\nsize = {frame_width, frame_height}\nmargin = 0.05\nfont_size = \"16pt\"\ntitle_font_size = \"18pt\"\nticks = [1, 2, 3, 4, 5, 6, 7]\n\n# Create and configure the plot\nx\n|> Matplotex.plot(y)                                # Create a line plot\n|> Matplotex.figure(%{                              # Configure the figure\n     figsize: size,\n     margin: margin\n   })","ref":"Matplotex.html#plot/2-example"},{"type":"function","title":"Matplotex.plot/3","doc":"","ref":"Matplotex.html#plot/3"},{"type":"function","title":"Matplotex.plot/4","doc":"Adds an additional dataset to a figure for creating multi-line plots.\n\nThis function allows you to overlay multiple datasets onto a single figure, enabling the creation of multi-line plots for better data visualization and comparison.","ref":"Matplotex.html#plot/4"},{"type":"function","title":"Parameters - Matplotex.plot/4","doc":"- `figure` (%Figure{}): The figure to which the new dataset will be added.\n- `x` (list): A list of x-coordinates for the new dataset.\n- `y` (list): A list of y-coordinates corresponding to the x-coordinates.","ref":"Matplotex.html#plot/4-parameters"},{"type":"function","title":"Usage - Matplotex.plot/4","doc":"Use this function when you need to generate multi-line plots with multiple datasets. Below is an example of its usage:\n\n```elixir\n# X-axis values\nx = [1, 2, 3, 4, 5]\n\n# Dataset 1\ny1 = [1, 4, 9, 16, 25]\n\n# Dataset 2\ny2 = [1, 3, 6, 10, 15]\n\n# Dataset 3\ny3 = [2, 5, 7, 12, 17]\n\n# Plotting multiple datasets on the same figure\nx\n|> Matplotex.plot(y1, color: \"blue\", linestyle: \"_\", marker: \"o\", label: \"Dataset 1\")\n|> Matplotex.plot(x, y2, color: \"red\", linestyle: \"--\", marker: \"^\", label: \"Dataset 2\")\n|> Matplotex.plot(x, y3, color: \"green\", linestyle: \"-.\", marker: \"s\", label: \"Dataset 3\")","ref":"Matplotex.html#plot/4-usage"},{"type":"function","title":"Matplotex.scatter/2","doc":"Creates a scatter plot based on the given `x` and `y` values, with optional customization provided via `opts`.","ref":"Matplotex.html#scatter/2"},{"type":"function","title":"Parameters - Matplotex.scatter/2","doc":"- `x` (list): A list of numerical values representing the x-coordinates.\n  - `y` (list): A list of numerical values representing the y-coordinates.\n  - `opts` (keyword list, optional): A set of options for customizing the scatter plot, such as color, marker size, and labels.","ref":"Matplotex.html#scatter/2-parameters"},{"type":"function","title":"Examples - Matplotex.scatter/2","doc":"```elixir\n# Basic usage:\nx = [1, 2, 3, 4]\ny = [10, 20, 30, 40]\nopts = [color: \"blue\", marker_size: 5]\n\niex> M.scatter(x, y, opts)\n %M.Figure{axes: %Matplotex.Figure.Areal.Scatter{...}, ...}","ref":"Matplotex.html#scatter/2-examples"},{"type":"function","title":"Matplotex.scatter/3","doc":"","ref":"Matplotex.html#scatter/3"},{"type":"function","title":"Matplotex.scatter/4","doc":"Adds an additional dataset to a scatter plot in the given `%Figure{}`.\n\nThis function allows you to overlay multiple scatter plots on the same figure by providing new `x` and `y` values, along with customization options via `opts`.","ref":"Matplotex.html#scatter/4"},{"type":"function","title":"Parameters - Matplotex.scatter/4","doc":"- `figure` (%Figure{}): The figure to which the new dataset will be added.\n  - `x` (list): A list of numerical values representing the x-coordinates of the new dataset.\n  - `y` (list): A list of numerical values representing the y-coordinates of the new dataset.\n  - `opts` (keyword list, optional): A set of options for customizing the appearance of the new dataset, such as color, marker style, line style, and labels.","ref":"Matplotex.html#scatter/4-parameters"},{"type":"function","title":"Usage - Matplotex.scatter/4","doc":"This function is typically used when you want to generate multi-pattern scatter plots with multiple datasets. The following example demonstrates its usage:\n\n```elixir\nx = [1, 2, 3, 4, 5]\n\n# Dataset 1\ny1 = [20, 5, 12, 16, 25]\n\n# Dataset 2\ny2 = [10, 1, 6, 10, 15]\n\n# Dataset 3\ny3 = [17, 5, 8, 12, 17]\n\nx\n|> Matplotex.scatter(y1, color: \"blue\", linestyle: \"_\", marker: \"o\", label: \"Dataset 1\")\n|> Matplotex.scatter(x, y2, color: \"red\", linestyle: \"--\", marker: \"^\", label: \"Dataset 2\")\n|> Matplotex.scatter(x, y3, color: \"green\", linestyle: \"-.\", marker: \"s\", label: \"Dataset 3\")","ref":"Matplotex.html#scatter/4-usage"},{"type":"function","title":"Matplotex.set_figure_size/2","doc":"","ref":"Matplotex.html#set_figure_size/2"},{"type":"function","title":"Matplotex.set_margin/2","doc":"","ref":"Matplotex.html#set_margin/2"},{"type":"function","title":"Matplotex.set_rc_params/2","doc":"Function to update rc params, rc stands for runtime configuration","ref":"Matplotex.html#set_rc_params/2"},{"type":"function","title":"Examples - Matplotex.set_rc_params/2","doc":"iex> Matplotex.set_rc_params(figure, figure_size: {10,6}, figure_dpi: 100)","ref":"Matplotex.html#set_rc_params/2-examples"},{"type":"function","title":"The RC params are - Matplotex.set_rc_params/2","doc":"figure_size: Figure size\n           figure_dpi: dots per inch\n           line_width: Main line width(axis, border, etc)\n           line_style: Main line style(\"--\", \"-\")\n           x_tick_font_size: X tick font size,\n           y_tick_font_size: Y tick font size\n           x_label_font_size: X label font size\n           y_label_font_size: y label font size\n           legend_font_size: Legends font size\n           legend_location: Legend location\n           title_font: Title font size\n           grid_color: grid color\n           grid_linestyle:  grid linestyle\n           grid_linewidth: grid line width\n           grid_alpha: grid line alpha\n           font_uom: font unit of measurement","ref":"Matplotex.html#set_rc_params/2-the-rc-params-are"},{"type":"function","title":"Matplotex.set_title/3","doc":"Sets Title for the graph with given font details","ref":"Matplotex.html#set_title/3"},{"type":"function","title":"Examples - Matplotex.set_title/3","doc":"iex> Matplotex.plot(x,y)\n         |> Matplotex.set_title(\"My Graph\", font_family: \"Arial\", font_size: 20, color: \"red\")\n    %Matplotex.Figure{}","ref":"Matplotex.html#set_title/3-examples"},{"type":"function","title":"Matplotex.set_xlabel/3","doc":"Sets X labels for the graph with given font details","ref":"Matplotex.html#set_xlabel/3"},{"type":"function","title":"Examples - Matplotex.set_xlabel/3","doc":"iex> Matplotex.set_xlabel(figure,\"X label\", font_family: \"Ariel\", font_size: 16, color: \"red\" )\n    %Matplotex.Figure{}","ref":"Matplotex.html#set_xlabel/3-examples"},{"type":"function","title":"Matplotex.set_xlim/2","doc":"Sets X and Y limits for the graph with given details","ref":"Matplotex.html#set_xlim/2"},{"type":"function","title":"Examples - Matplotex.set_xlim/2","doc":"iex> Matplotex.set_xlim(figure, {1,10})\n    %Matplotex.Figure{}","ref":"Matplotex.html#set_xlim/2-examples"},{"type":"function","title":"Matplotex.set_xticks/2","doc":"Sets X tick labels for the graph with given font details","ref":"Matplotex.html#set_xticks/2"},{"type":"function","title":"Examples - Matplotex.set_xticks/2","doc":"iex> Matplotex.set_xticks(figure, [1, 2, 3,4,5,6,7,8])\n    %Matplotex.Figure{}","ref":"Matplotex.html#set_xticks/2-examples"},{"type":"function","title":"Matplotex.set_ylabel/3","doc":"Sets Y label for the graph with given font details","ref":"Matplotex.html#set_ylabel/3"},{"type":"function","title":"Examples - Matplotex.set_ylabel/3","doc":"iex> Matplotex.set_ylabel(figure, \"Y label\", [font_family: \"Ariel\", font_size: 16, color: \"green\"])\n    %Matplotex.Figure{}","ref":"Matplotex.html#set_ylabel/3-examples"},{"type":"function","title":"Matplotex.set_ylim/2","doc":"Sets Y limit for the graph with given details","ref":"Matplotex.html#set_ylim/2"},{"type":"function","title":"Examples - Matplotex.set_ylim/2","doc":"iex> Matplotex.set_ylim(figure, {10,50})\n    %Matplotex.Figure{}","ref":"Matplotex.html#set_ylim/2-examples"},{"type":"function","title":"Matplotex.set_yticks/2","doc":"Sets Y tick labels for the graph with given details","ref":"Matplotex.html#set_yticks/2"},{"type":"function","title":"Examples - Matplotex.set_yticks/2","doc":"iex> Matplotex.set_yticks(figure, [10, 20, 30, 40, 50])\n    %Matplotex.Figure{}","ref":"Matplotex.html#set_yticks/2-examples"},{"type":"function","title":"Matplotex.show/1","doc":"","ref":"Matplotex.html#show/1"},{"type":"function","title":"Matplotex.show_legend/1","doc":"","ref":"Matplotex.html#show_legend/1"},{"type":"function","title":"Matplotex.spline/2","doc":"Generates a spline graph based on the provided datasets.\n\nThis function creates a smooth curve that connects the data points (x, y) using spline interpolation, ideal for visualizing continuous relationships between two variables.","ref":"Matplotex.html#spline/2"},{"type":"function","title":"Parameters - Matplotex.spline/2","doc":"- `x` (list): A list of x-coordinates for the data points.\n- `y` (list): A list of y-coordinates corresponding to the x-coordinates.\n- `opts` (keyword list, optional): A list of additional configuration options for the plot. These can include attributes like `color`, `line_style`, `marker`, `x_label`, `y_label`, and more.","ref":"Matplotex.html#spline/2-parameters"},{"type":"function","title":"Example - Matplotex.spline/2","doc":"```elixir\n# Generate x and y data\nx_nx = Nx.linspace(0, 10, n: 100)\nx = Nx.to_list(x_nx)\ny = x_nx |> Nx.sin() |> Nx.to_list()\n\n# Plot a spline graph with optional configurations\nMatplotex.spline(x, y, x_label: \"X\", y_label: \"Y\", edge_color: \"green\")","ref":"Matplotex.html#spline/2-example"},{"type":"function","title":"Matplotex.spline/3","doc":"","ref":"Matplotex.html#spline/3"},{"type":"function","title":"Matplotex.spline/4","doc":"Adds an additional spline to an existing spline graph.\n\nThis function allows you to extend an existing spline plot by adding another spline with different data points. It is ideal for comparing multiple datasets on the same plot.","ref":"Matplotex.html#spline/4"},{"type":"function","title":"Parameters - Matplotex.spline/4","doc":"- `figure` (%Figure{}): The existing figure (spline graph) to which the new spline will be added.\n- `x` (list): A list of x-coordinates for the new spline.\n- `y` (list): A list of y-coordinates corresponding to the x-coordinates for the new spline.\n- `opts` (keyword list, optional): Additional configuration options for the plot. This can include attributes like:\n  - `color`: The color of the spline.\n  - `line_style`: The style of the line (e.g., dashed, solid, etc.).\n  - `marker`: Marker style for the data points (e.g., circle, square, etc.).\n  - `label`: Label for the new spline.","ref":"Matplotex.html#spline/4-parameters"},{"type":"function","title":"Example - Matplotex.spline/4","doc":"```elixir\n# Generate x and y data\nx_nx = Nx.linspace(0, 10, n: 100)\nx = Nx.to_list(x_nx)\ny1 = x_nx |> Nx.sin() |> Nx.to_list()\ny2 = x_nx |> Nx.cos() |> Nx.to_list()\n\n# Create an initial spline and add another one\nMatplotex.spline(x, y1, x_label: \"X\", y_label: \"Y\", edge_color: \"green\")\n|> Matplotex.spline(x, y2, x_label: \"X\", y_label: \"Y\", edge_color: \"red\")","ref":"Matplotex.html#spline/4-example"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.36.1"}}